# Changelog
All notable changes to this project will be documented in this file.


## v0.12.0 -  2020-09-21  - Documentation and Bugfixes

### general:
- improved documentation include installation instructions and many examples from the paper, #153 
- bugfixes (see technical)

### new features:
- `MyLittleModel` is now a pure feed-forward network (before it had a CNN part), #168

### technical:
- new compile options check to ensure its execution, #154 
- bugfix for key errors in time series plot, #169 
- bugfix for not used kwargs in `DefaultDataHandler`, #170 
- `trainable` parameter is renamed by `train_model` to prevent confusion with the tf trainable parameter, #162 
- fixed HPC installation failure, #159


## v0.11.0 -  2020-08-24  -  Advanced Data Handling for MLAir

### general
- Introduce advanced data handling with much more flexibility (independent of TOAR DB, custom data handling is 
  pluggable), #144
- default data handler is still using TOAR DB

### new features
- default data handler using TOAR DB refactored according to advanced data handling, #140, #141, #152
- data sets are handled as collections, #142, and are iterable in a standard way (StandardIterator) and optimised for 
  keras (KerasIterator), #143
- automatically moving station map plot, #136

### technical 
- model modules available from package, #139 
- renaming of parameter time dimension, #151
- refactoring of README.md, #138


## v0.10.0 -  2020-07-15  -  MLAir is official name, Workflows, easy Model plug-in

### general
- Official project name is released: MLAir (Machine Learning on Air data)
- a model class can now easily be plugged in into MLAir. #121
- introduced new concept of workflows, #134

### new features
- workflows are used to execute a sequence of run modules, #134
- default workflows for standard and the Juelich HPC systems are available, custom workflows can be defined, #134
- seasonal decomposition is available for conditional quantile plot, #112
- map plot is created with coordinates, #108
- `flatten_tails` are now more general and easier to customise, #114
- model classes have custom compile options (replaces `set_loss`), #110
- model can be set in ExperimentSetup from outside, #121
- default experiment settings can be queried using `get_defaults()`, #123
- training and model settings are reported as MarkDown and Tex tables, #145

### technical
- Juelich HPC systems are supported and installation scripts are available, #106
- data store is tracked, I/O is saved and illustrated in a plot, #116
- batch size, epoch parameter have to be defined in ExperimentSetup, #127, #122
- automatic documentation with sphinx, #109
- default experiment settings are updated, #123
- refactoring of experiment path and its default naming, #124
- refactoring of some parameter names, #146
- preparation for package distribution with pip, #119
- all run scripts are updated to run with workflows, #134
- the experiment folder is restructured, #130


## v0.9.0  -  2020-04-15  -  faster bootstraps, extreme value upsamling
### general
- improved and faster bootstrap workflow
- new plot PlotAvailability
- extreme values upsampling
- improved runtime environment

### new features
- entire bootstrap workflow has been refactored and much faster now, can be skipped with `evaluate_bootstraps=False`, #60
- upsampling of extreme values, set with parameter `extreme_values=[your_values_standardised]` (e.g. `[1, 2]`) and 
  `extremes_on_right_tail_only=<True/False>` if only right tail of distribution is affected or both, #58, #87
- minimal data length property (in total and for all subsets), #76
- custom objects in model class to load customised model objects like padding class, loss, #72
- new plot for data availability: `PlotAvailability`, #103
- introduced (default) `plot_list` to specify which plots to draw
- latex and markdown information on sample sizes for each station, #90

### technical
- implemented tests on gpu and from scratch for develop, release and master branches, #95
- usage of tensorflow 1.13.1 (gpu / cpu), separated in 2 different requirements, #81
- new abstract plot class to have uniform plot class design
- New time tracking wrapper to use for functions or classes
- improved logger (info on display, debug into file), #73, #85, #88
- improved run environment, especially for error handling, #86
- prefix `general` in data store scope is now optional and can be skipped. If given scope is not `general`, it is 
  treated as subscope, #82
- all 2D Padding classes are now selected by `Padding2D(padding_name=<padding_type>)` e.g. 
  `Padding2D(padding_name="SymPad2D")`, #78
- custom learning rate (or lr_decay) is optional now, #71

